#
# spec file for package OpenBoard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         namelc openboard
%define         fqname ch.%{namelc}.%{name}
Name:           OpenBoard
Version:        1.7.1
Release:        3.0.2.1.sr20240702
Summary:        Interactive whiteboard for schools and universities
License:        GPL-3.0-or-later
Group:          Amusements/Teaching/Other
URL:            https://openboard.ch
Source0:        https://github.com/OpenBoard-org/OpenBoard/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# https://github.com/OpenBoard-org/OpenBoard/pull/569
Patch569:       0569-scale-mirror-pixmap.patch
# https://github.com/OpenBoard-org/OpenBoard/pull/955
Patch955:       0955-shortcut-configuration.patch
# https://github.com/OpenBoard-org/OpenBoard/pull/961
Patch961:       0961-use-cpp20.patch
# https://github.com/OpenBoard-org/OpenBoard/pull/962
Patch962:       0962-fix-cpp20-compatibility.patch
# https://github.com/OpenBoard-org/OpenBoard/pull/1010
Patch1010:      1010-fix-qapp-cast.patch
# https://github.com/letsfindaway/OpenBoard/pull/117
Patch9117:      9117-disable-software-update.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5MultimediaWidgets)
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5UiTools)
BuildRequires:  cmake(Qt5WebEngineWidgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(poppler)
BuildRequires:  pkgconfig(quazip1-qt5)
Recommends:     onboard

%description
OpenBoard is an open source cross-platform interactive white board
application designed primarily for use in schools. It was
originally forked from Open-Sankoré, which was itself based on
Uniboard.

%prep
%autosetup -p1 -n %{name}-%{version}

%build
%if 0%{?suse_version} < 1600
%cmake
%else
%cmake -DCMAKE_CXX_STANDARD=20
%endif
%cmake_build

%install
%cmake_install
%fdupes -s %{buildroot}

%files
%license LICENSE
%doc COPYRIGHT
%{_datadir}/applications/%{fqname}.desktop
%{_datadir}/icons/hicolor/scalable
%{_datadir}/mime/packages/*
%{_datadir}/%{namelc}
%{_bindir}/%{namelc}
%config %{_sysconfdir}/%{namelc}

%changelog
* Thu Jul  4 2024 Martin Winter <me@letsfindaway.de>
- compatibility with poppler >= 24.05
  * poppler >= 24.05 requires c++20
  * add 0961-use-cpp20.patch
  * add 0962-fix-cpp20-compatibility.patch
  * both patches are already merged upstream
    and will be part of the next release
* Sun Jun  9 2024 Martin Winter <me@letsfindaway.de>
- fix a problem with latest plasma5 security patches
  * add 1010-fix-qapp-cast.patch
* Wed May  8 2024 Martin Winter <me@letsfindaway.de>
- update to release version 1.7.1
- remove upstreamed patches
  * remove 0830-cmake-community-builds.patch
  * remove 9686-cmake-add-shortcut-manager.patch
- update patch to match updated sources
  * replace 0686-shortcut-configuration.patch by 0955-shortcut-configuration.patch
* Sat Dec  9 2023 Martin Winter <me@letsfindaway.de>
- update to release version 1.7.0
- update patches to match updated sources
  * update 0569-scale-mirror-pixmap.patch
  * update 0686-shortcut-configuration.patch
- replace build system patch
  * remove 0698-add-cmake-build-system.patch
  * add 0830-cmake-community-builds.patch
- switch from pgkconfig to cmake for some BuildRequires
* Sun Jun 18 2023 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0~git20230614.2ff8f29
  * feature freeze before release
- remove upstreamed patches
  * remove upstreamed 0551-common-background-drawing.patch
  * remove upstreamed 0677-pdf-export-page-size.patch
- update patches to match updated sources
  * update 0686-shortcut-configuration.patch
  * update 0698-add-cmake-build-system.patch
  * update 9117-disable-software-update.patch
* Wed Jan 25 2023 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libavdevice) instead of ffmpeg-devel: let
  OBS figure out the right packages that do not conlfict.
* Tue Nov 29 2022 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0~git20221129.9de37af
- feat: user configurable shortcuts
  * replace 0460-shortcut-configuration.patch by updated
    0686-shortcut-configuration.patch
  * add 9686-cmake-add-shortcut-manager.patch
    add new files to CMakeLists.txt
- fix: background drawing when switching page size
  * update 0551-common-background-drawing.patch
- fix: mirror pixmap size
  * update 0569-scale-mirror-pixmap.patch
- remove upstreamed patches
  * remove upstreamed 0604-qt-5.12-compatibility.patch
  * remove upstreamed 0629-bug-ruler.patch
  * remove upstreamed 0633-improve-displaymanager.patch
  * remove upstreamed 0637-fix-pdf-background-export.patch
  * remove upstreamed 0641-fix-font-handling.patch
  * remove upstreamed 0649-fix-pdf-export-scaling.patch
- chore: replace qmake by cmake build system
  * remove 0651-chore-reorganize-linux-build.patch
  * add 0698-add-cmake-build-system.patch
- fix: page size for PDF export
  * add 0677-pdf-export-page-size.patch
- disable software update from openboard web page
  * add 9117-disable-software-update.patch
* Tue Sep 20 2022 Martin Winter <me@letsfindaway.de>
- fix file list in spec file
  - do not include /usr/share/mime/packages directory owned by
    filesystem
* Wed Sep 14 2022 Martin Winter <me@letsfindaway.de>
- update to version 1.7.0~git20220914.47a96e1
- feat: user configurable shortcuts
  * add 0460-shortcut-configuration.patch
- fix: boxing in single screen mode
  * update 0633-improve-displaymanager.patch
- fix: PDF background export
  * update 0637-fix-pdf-background-export.patch
- fix: font handling
  * update 0641-fix-font-handling.patch
- fix: PDF export scaling
  * add 0649-fix-pdf-export-scaling.patch
- refactor: Linux build and installation
  * add 0651-chore-reorganize-linux-build.patch
  * replaces 0001-Rewrite-libs.pri.patch
  * replaces 0002-Install-to-correct-directories-on-linux.patch
  * replaces 0003-podcast.pri-port-to-pkgconfig.patch
  * replaces 0004-Use-QStandardPaths-to-locate-resources.patch
  * replaces 0005-Add-svg-icon.patch
  * replaces 0006-pro-Remove-UB_THIRDPARTY_INTERACTIVE.patch
  * replaces 0007-Linux-Only-use-onboard-by-default-if-it-s-installed.patch
  * replaces 0008-install-fonts.patch
  * add mimespec for .ubz files
  * also improve handling of onboard on-screen keyboard
- refactor: clean spec file
* Fri Jun 24 2022 Martin Winter <me@letsfindaway.de>
- minor changes in spec file
* Fri Jun 24 2022 Martin Winter <me@letsfindaway.de>
- fix several issues
  - add 0008-install-fonts.patch
  - add 0637-fix-pdf-background-export.patch
  - add 0641-fix-font-handling.patch
* Sun Jun 19 2022 Martin Winter <me@letsfindaway.de>
- update to 1.7.0~git47a96e1
  - use development branch to enable build for Tumbleweed
    (switch from QWebKit to QWebEngine)
- add patches fixing known issues according to existing upstream PRs
  - 0551-common-background-drawing.patch
  - 0569-scale-mirror-pixmap.patch
  - 0604-qt-5.12-compatibility.patch
  - 0629-bug-ruler.patch
  - 0633-improve-displaymanager.patch
- remove unused build dependencies
* Mon Jun 13 2022 Martin Winter <me@letsfindaway.de>
- Update to 1.6.3
  - see https://github.com/OpenBoard-org/OpenBoard/releases/tag/v1.6.3
* Mon Jun  6 2022 Martin Winter <me@letsfindaway.de>
- Update to 1.6.2
  - see https://github.com/OpenBoard-org/OpenBoard/releases/tag/v1.6.2
  - adapt 0001-Rewrite-libs.pri.patch
  - adapt 0002-Install-to-correct-directories-on-linux.patch
  - drop 0573-compile-with-poppler-22.03.patch (upstreamed)
* Tue Mar 15 2022 Martin Winter <me@letsfindaway.de>
- add 0573-compile-with-poppler-22.03.patch
* Tue Dec 28 2021 Martin Winter <martin@winter-rosenheim.de>
- update to OpenBoard 1.6.1
  - adapt patches
* Mon Feb  8 2021 Adam Majer <adam.majer@suse.de>
- Compile translations so they are installed (bsc#1181857)
* Mon Nov 23 2020 Adam Majer <adam.majer@suse.de>
- 0001-Rewrite-libs.pri.patch:
  + update patch and BR on now weirdly named quazip - pkgconfig(quazip1-qt5)
  + continue to function with with pkgconfig(quazip) in Leap 15.2
- Remove BR on libx264-devel and fdk-aac-devel as these are no longer
  available in Factory
* Sat May 23 2020 Frank Schütte <F.Schuette@t-online.de>
- fixed building with patches from https://github.com/flathub/ch.openboard.OpenBoard
* Fri May 22 2020 Frank Schütte <F.Schuette@t-online.de>
- update to 1.5.4
* Mon Jun 10 2019 Frank Schütte <F.Schuette@t-online.de>
- remove openssl patch
* Mon Jun 10 2019 Frank Schütte <F.Schuette@t-online.de>
- Update to OpenBoard 1.5.3
- updated OpenBoard-no-Third-Party patch
* Fri Jan 25 2019 F.Schuette@t-online.de
- Update to OpenBoard 1.5.2
* Tue Sep 11 2018 F.Schuette@t-online.de
- Update to OpenBoard 1.4.1
  * Add patch for ffmpeg includes.
* Wed Jan 10 2018 antoine.belvire@opensuse.org
- Add compatibility with OpenSSL 1.1 API:
  * OpenBoard-1.3.6-add-openssl-1.1-compat.patch.
  * Authorize build with OpenSSL 1.1 by removing version constraint
    on "BuildRequires".
- Merge quazip_libname.patch with OpenBoard-no_Third-Party.patch.
* Tue Jan  9 2018 antoine.belvire@opensuse.org
- Update to version 1.3.6:
  * Fix several issues relating to copy-pasting and
    cut-and-pasting elements from one page or document to another.
  * Fix an issue where pen strokes that had been erased with the
    eraser would reappear after saving and loading.
  * Fix an issue where duplicating a pen stroke that had been
    moved could cause the new stroke to be placed in the wrong
    position.
  * Fix an issue where strokes could be badly placed after using
    the "undo" and "redo" functions.
  * Fix an issue where compass strokes were not saved (when
    making several strokes, only the first one was saved).
  * Fix an issue where pages could be truncated when exporting to
    PDF.
  * Fix an issue where locked items could be moved when part of a
    multiple selection
  * (Document mode) Fix document selection after deleting a
    trashed document.
  * Tweak the background grid color for the dark background.
  * The mask tool can now be resized non-proportionately.
  * Re-implemented automatic update checking, which will appear
    to users when the next version is released.
- Changes from version 1.3.5:
  * Fix detection of "cloned" multi-monitor setups to avoid
    multi-screen mode being activated in this configuration.
    [Note: some problems remain with multi-monitor setups on some
    Linux versions.].
  * Text items: Text can no longer be selected or edited if the
    text item is marked as non-editable through its menu.
  * Text items: On page load, text items no longer take keyboard
    focus.
  * Library pane: Fix moving of items (upon moving an item to a
    folder, the item would not immediately disappear from its
    current location).
  * Library pane: Fix nested folder issue in breadcrumbs trail (two
    folders that were at the same path and whose names started with
    the same characters were considered by the breadcrumbs trail to
    be nested).
  * Document view: Fix folder names not being saved after renaming
    them.
  * Fix audio item saving (v1.3.3 bug): Documents containing an
    audio item were saved incorrectly, making the audio unplayable
    upon page load.
  * Desktop mode: Eraser and marker preview circles now disappear
    when the cursor hovers over the left or right-hand toolbars, as
    in board mode.
- Drop OpenBoard-fix-call-of-overloaded-abs-is-ambiguous.patch
  (fixed upstream).
- Fix some rpmlint warnings.
* Tue Jan  9 2018 antoine.belvire@opensuse.org
- Fix build:
  * Change OpenBoard-XPDFRenderer_with_poppler.patch to make it
    work with libpoppler >= 0.55.
  * Force use of OpenSSL 1.0 as build requirement instead of 1.1.
  * Use "libquazip-qt5-devel" instead of "quazip-qt5-devel" in
    build requirements to fix build on Leap.
* Fri Jun 30 2017 adam.majer@suse.de
- quazip_libname.patch: Use quazip-qt5 instead of quazip as mixing
  Qt versions is bad. Qt5 quazip also uses a different library
  name. (boo#1042040)
- add missing libpulse BuildRequires
* Mon Feb 13 2017 mrueckert@suse.de
- update to 1.3.4
  - OS X: fixed desktop drop shadow bug: when switching from
    desktop mode to board mode and back, shadows were drawn behind
    annotations; these persisted even if the annotation was erased
  - Windows: Updated bundled Visual C++ runtime library; fixed
    installer so that the library installation would be silent (no
    more dialog box appearing)
  - Linux: fixed detection of "cloned" multi-monitor setups to
    avoid multi-screen mode being activated in this configuration.
    [Note: some problems remain with multi-monitor setups on some
    Linux versions; see Known Issues]
  - Text items: text can no longer be selected or edited if the
    text item is marked as non-editable through its menu
  - Text items: on page load, text items no longer take keyboard
    focus
  - Library pane: fixed moving of items (upon moving an item to a
    folder, the item would not immediately disappear from its
    current location)
  - Library pane: fixed nested folder issue in breadcrumbs trail
    (two folders that were at the same path and whose names started
    with the same characters were considered by the breadcrumbs
    trail to be nested)
  - Document view: fixed folder names not being saved after
    renaming them
  - Fixed audio item saving (v1.3.3 bug): documents containing an
    audio item were saved incorrectly, making the audio unplayable
    upon page load
  - Desktop mode: eraser and marker preview circles now disappear
    when the cursor hovers over the left or right-hand toolbars, as
    in board mode
- refreshed OpenBoard-XPDFRenderer_with_poppler.patch to apply
  cleanly again
